@@ -1,6 +1,5 @@
-import urllib
 import typing
-
+import urllib
 from collections import defaultdict
 
 
@@ -8,9 +7,7 @@ class UrlManager:
     def __init__(self, base_url: str, paths: list) -> None:
         parsed_url = urllib.parse.urlparse(base_url)
 
-        assert (
-            parsed_url.scheme
-        ), f"The url does not have a schema, add one. For example http://{base_url}"
+        assert parsed_url.scheme, f"The url does not have a schema, add one. For example http://{base_url}"
 
         # this is the absolute url to the server
         self.base_url = base_url
